@@ -51,15 +51,15 @@ import click
 import deprecation_alias
 from domdf_python_tools.stringlist import StringList
 from domdf_python_tools.words import SANS_SERIF_ITALIC_LETTERS
-from mistletoe import block_token, span_token  # type: ignore
-from mistletoe.base_renderer import BaseRenderer  # type: ignore
+from mistletoe import block_token, span_token  # type: ignore[import]
+from mistletoe.base_renderer import BaseRenderer  # type: ignore[import]
 from typing_extensions import TypeGuard
 
 # this package
 from consolekit import terminal_colours, tracebacks
 from consolekit.terminal_colours import ColourTrilean, resolve_color_default
 
-__all__ = [
+__all__ = (
 		"get_env_vars",
 		"is_command",
 		"import_commands",
@@ -74,12 +74,12 @@ __all__ = [
 		"TerminalRenderer",
 		"hidden_cursor",
 		"long_echo",
-		]
+		)
 
 _deprecator = deprecation_alias.deprecated(
 		deprecated_in="1.0.0",
 		removed_in="2.0.0",
-		current_version="1.4.0",
+		current_version="1.8.1",
 		details="Import from consolekit.tracebacks instead."
 		)
 
@@ -87,7 +87,7 @@ handle_tracebacks = _deprecator(tracebacks.handle_tracebacks)
 traceback_handler = _deprecator(tracebacks.traceback_handler)
 
 
-def get_env_vars(ctx, args, incomplete):  # noqa: D103
+def get_env_vars(ctx, args, incomplete) -> List[str]:  # noqa: D103,MAN001
 	return [k for k in os.environ.keys() if incomplete in k]
 
 
@@ -332,10 +332,10 @@ def hidden_cursor() -> Iterator:
 
 
 @lru_cache(1)
-def _pycharm_terminal():
+def _pycharm_terminal() -> bool:
 	try:
 		# 3rd party
-		import psutil  # type: ignore  # nodep
+		import psutil  # type: ignore[import]  # nodep
 
 		parent_process = psutil.Process(os.getppid())
 		grandparent_process = psutil.Process(parent_process.ppid())
@@ -452,7 +452,7 @@ class TerminalRenderer(BaseRenderer):
 			return f" * {self.render_inner(token).lstrip()}"
 
 	@staticmethod
-	def render_line_break(token):
+	def render_line_break(token) -> str:  # noqa: MAN001
 		"""
 		Render a line break in a multiline paragraph.
 
@@ -461,7 +461,7 @@ class TerminalRenderer(BaseRenderer):
 
 		return ' '
 
-	def render(self, token) -> str:
+	def render(self, token) -> str:  # noqa: MAN001
 		"""
 		Render the given token for display in a terminal.
 
